@@ -44,9 +44,10 @@ void messageHandler(QtMsgType type, const QMessageLogContext &context, const QSt
 
 int main(int argc, char *argv[])
 {
-    if (!getenv("XDG_CURRENT_DESKTOP")) {
+    const bool defskin = (!getenv("QT_QPA_PLATFORMTHEME") && !getenv("XDG_CURRENT_DESKTOP"));
+    if (defskin) {
         // The default style in the OOBE environment is hideous and unusable.
-        QApplication::setStyle("windows"); // Qt docs say do this before the QApplication instance.
+        QApplication::setStyle("cde"); // Qt docs say do this before the QApplication instance.
         QPalette pal;
         pal.setColor(QPalette::Window, Qt::black);
         pal.setColor(QPalette::WindowText, Qt::white);
@@ -68,6 +69,7 @@ int main(int argc, char *argv[])
     }
 
     QApplication a(argc, argv);
+    if (defskin) a.setStyleSheet("QDialog { border: 2px ridge gray; }");
     a.setApplicationVersion(VERSION);
     a.setWindowIcon(QIcon("/usr/share/gazelle-installer-data/logo.png"));
     QTranslator qtTran;
@@ -114,7 +116,9 @@ int main(int argc, char *argv[])
             "-- doesn't format /root and it doesn't work with encryption.")},
         {"media-check", QObject::tr("Always check the installation media at the beginning.")},
         {"no-media-check", QObject::tr("Do not check the installation media at the beginning.\n"
-            "Not recommended unless the installation media is guaranteed to be free from errors.")}});
+            "Not recommended unless the installation media is guaranteed to be free from errors.")},
+        // TODO: Eliminate --good-luks when MX Boot Repair is fixed. No translations needed.
+        {"good-luks", "Use luks-<UUID> mapping name for all LUKS containers, including root."}});
     parser.addPositionalArgument("config-file", QObject::tr("Load a configuration file as specified by <config-file>."), "<config-file>");
     parser.process(a);
 
