@@ -164,8 +164,6 @@ void MInstall::startup()
             checkmd5 = nullptr;
         }
 
-        setupZRam(); // Start zram swap. In particular, the Argon2id KDF for LUKS uses a lot of memory.
-
         partman = new PartMan(proc, *this, appConf, appArgs);
         base = new Base(proc, *partman, *this, appConf, appArgs);
         bootman = new BootMan(proc, *partman, *this, appConf, appArgs);
@@ -360,6 +358,8 @@ bool MInstall::processNextPhase() noexcept
             proc.advance(-1, -1);
             proc.status(tr("Preparing to install %1").arg(PROJECTNAME));
 
+            setupZRam(); // Start zram swap. In particular, the Argon2id KDF for LUKS uses a lot of memory.
+
             // Load defaults for configuration phase
             bootman->buildBootLists();
             swapman->setupDefaults();
@@ -515,6 +515,7 @@ void MInstall::manageConfig(enum ConfigAction mode) noexcept
         config->sync();
         QFile::remove("/etc/minstalled.conf");
         QFile::copy(config->fileName(), "/etc/minstalled.conf");
+        chmod(config->fileName().toUtf8().constData(), 0600);
     }
 
     if (config->bad) {
@@ -1086,7 +1087,12 @@ void MInstall::cleanup()
 
     if (config) config->dumpDebug();
     else qDebug() << "NO CONFIG";
-    proc.exec("cp", {"/var/log/minstall.log", "/mnt/antiX/var/log"});
+    const char *destlog = "/mnt/antiX/var/log/minstall.log";
+    QFile::remove(destlog);
+    bool ok = QFile::copy("/var/log/minstall.log", destlog);
+    if (ok) ok = (chmod(destlog, 0400) == 0);
+    if (!ok) proc.log("Failed to copy the installation log to the target.", MProcess::LOG_FAIL);
+
     proc.exec("rm", {"-rf", "/mnt/antiX/mnt/antiX"});
     if (!mountkeep) partman->clearWorkArea();
     setupAutoMount(true);
