@@ -168,6 +168,7 @@ class PartMan : public QAbstractItemModel
     DeviceItem *changing = nullptr;
     Ui::MeInstall &gui;
     bool brave, gptoverride;
+    bool goodluks; // TODO: Eliminate when MX Boot Repair is fixed.
     void scanVirtualDevices(bool rescan);
     void resizeColumnsToFit() noexcept;
     void preparePartitions();
@@ -191,7 +192,7 @@ class PartMan : public QAbstractItemModel
     bool confirmSpace(class QMessageBox &msgbox) noexcept;
     bool confirmBootable(class QMessageBox &msgbox) noexcept;
     void luksFormat();
-    void luksOpen(DeviceItem *partit, const QString &luksfs, const QByteArray &password);
+    void luksOpen(DeviceItem *partit, const QByteArray &password);
 public:
     enum TreeColumns {
         Device,
